# Changelog

## v0.2.6

- feat: new way to use models of the same kind with an interface compatible with all providers (ModelKind TypeAlias)
- fix: wrong input/output token calculation in GoogleGenerationProvider
- feat: tool support in OpenAI and Cerebras
